<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&lt;h2&gt;%1 Client %2&lt;/h2&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&lt;h5&gt; REV %1 &lt;/h5&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>About</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Check For Updates</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AccountManager</name>
    <message>
        <source>failed to open account database</source>
        <translation>hesap veritabanı açılamadı</translation>
    </message>
    <message>
        <source>Authorization expired, please re-login</source>
        <translation>Yetkilendirme süresi doldu, lütfen yeniden giriş yapın.</translation>
    </message>
</context>
<context>
    <name>AccountSettingsDialog</name>
    <message>
        <source>Account Settings</source>
        <translation>Hesap Ayarları</translation>
    </message>
    <message>
        <source>Please enter the server address</source>
        <translation>Lütfen sunucu adresini girin</translation>
    </message>
    <message>
        <source>%1 is not a valid server address</source>
        <translation>%1 geçerli bir sunucu adresi değil</translation>
    </message>
    <message>
        <source>Failed to save account information</source>
        <translation>Hesap bilgileri kaydedilemedi</translation>
    </message>
    <message>
        <source>Failed to save the changes: %1</source>
        <translation>Değişiklikler kaydedilemedi: %1</translation>
    </message>
    <message>
        <source>Successfully updated current account information</source>
        <translation>Mevcut hesap bilgileri başarıyla güncellendi</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Server Address</source>
        <translation>Sunucu Adresi</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Eposta</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Tamam</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal et</translation>
    </message>
</context>
<context>
    <name>AccountView</name>
    <message>
        <source>Are you sure you want to remove account %1?&lt;br&gt;&lt;br&gt;The account will be removed locally. All syncing configuration will be removed too. The account at the server will not be affected.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to unsync libraries of this account: %1</source>
        <translation>Hesaba ait kütüphanelerin senkronizasyonu durdurulamadı: %1</translation>
    </message>
    <message>
        <source>click to open the website</source>
        <translation>websitesini açmak için tıklayın</translation>
    </message>
    <message>
        <source>pro version</source>
        <translation>pro versiyon</translation>
    </message>
    <message>
        <source>No account</source>
        <translation>Hesap yok</translation>
    </message>
    <message>
        <source>Choose</source>
        <translation>Seç</translation>
    </message>
    <message>
        <source>Account settings</source>
        <translation>Hesap ayarları</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Giriş yap</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
    <message>
        <source>Add an account</source>
        <translation>Bir hesap ekleyin</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Çıkış yap</translation>
    </message>
    <message>
        <source>not logged in</source>
        <translation>giriş yapılmadı</translation>
    </message>
    <message>
        <source>Failed to remove local repos sync token: %1</source>
        <translation>Yerel depoların senkronizasyon repolarını kaldırma başarısız: %1</translation>
    </message>
    <message>
        <source>Failed to get repo sync information from server: %1</source>
        <translation>Sunucudan repo senkronizasyon bilgisi alınamadı: %1</translation>
    </message>
    <message>
        <source>Form</source>
        <translation>Form</translation>
    </message>
    <message>
        <source>Account</source>
        <translation>Hesap</translation>
    </message>
    <message>
        <source>email</source>
        <translation>eposta</translation>
    </message>
    <message>
        <source>server</source>
        <translation>sunucu</translation>
    </message>
</context>
<context>
    <name>ActivitiesTab</name>
    <message>
        <source>File Activities are only supported in %1 Server Professional Edition.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>retry</source>
        <translation>tekrar dene</translation>
    </message>
    <message>
        <source>Failed to get actvities information. Please %1</source>
        <translation>Etkinlikler bilgisi alınamadı. Lütfen %1</translation>
    </message>
</context>
<context>
    <name>AutoUpdateManager</name>
    <message>
        <source>Upload Success</source>
        <translation>Yükleme başarılı</translation>
    </message>
    <message>
        <source>File &quot;%1&quot;
uploaded successfully.</source>
        <translation>Dosya &quot;%1&quot;
başarıyla yüklendi.</translation>
    </message>
    <message>
        <source>File &quot;%1&quot;
failed to upload.</source>
        <translation>Dosya &quot;%1&quot;
yüklenemedi.</translation>
    </message>
    <message>
        <source>Permission Error!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Authorization expired</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File does not exist</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The file is locked by %1, please try again later</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Upload Failure: %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AvatarService</name>
    <message>
        <source>Failed to create avatars folder</source>
        <translation>Avatar klasörü oluşturma başarısız</translation>
    </message>
</context>
<context>
    <name>CheckRepoRootDirPermDialog</name>
    <message>
        <source>Checking Permission</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CloneTasksDialog</name>
    <message>
        <source>Download tasks</source>
        <translation>İndirme görevleri</translation>
    </message>
    <message>
        <source>remove all successful tasks</source>
        <translation>tüm başarılı görevleri kaldır</translation>
    </message>
    <message>
        <source>No download tasks right now.</source>
        <translation>Şu anda indirme görevi yok.</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Temizle</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
</context>
<context>
    <name>CloneTasksTableModel</name>
    <message>
        <source>Library</source>
        <translation>Kütüphane</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Yol</translation>
    </message>
</context>
<context>
    <name>CloneTasksTableView</name>
    <message>
        <source>Cancel this task</source>
        <translation>Bu görevi iptal et</translation>
    </message>
    <message>
        <source>cancel this task</source>
        <translation>bu görevi iptal et</translation>
    </message>
    <message>
        <source>Remove this task</source>
        <translation>Bu görevi kaldır</translation>
    </message>
    <message>
        <source>Failed to cancel this task:

 %1</source>
        <translation>Bu görev iptal edilemedi:

 %1</translation>
    </message>
    <message>
        <source>Failed to remove this task:

 %1</source>
        <translation>Bu görev kaldırılamadı:

 %1</translation>
    </message>
</context>
<context>
    <name>CloudView</name>
    <message>
        <source>Minimize</source>
        <translation>Küçült</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <source>Libraries</source>
        <translation>Kütüphaneler</translation>
    </message>
    <message>
        <source>Starred</source>
        <translation>Yıldızlı</translation>
    </message>
    <message>
        <source>Activities</source>
        <translation>Etkinlikler</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Ara</translation>
    </message>
    <message>
        <source>current download rate</source>
        <translation>güncel indirme oranı</translation>
    </message>
    <message>
        <source>current upload rate</source>
        <translation>güncel yükleme oranı</translation>
    </message>
    <message>
        <source>Please Choose a folder to sync</source>
        <translation>Lütfen senkronize etmek için bir klasör seçiniz</translation>
    </message>
    <message>
        <source>no server connected</source>
        <translation>bağlı sunucu yok</translation>
    </message>
    <message>
        <source>all servers connected</source>
        <translation>tüm sunucular bağlı</translation>
    </message>
    <message>
        <source>some servers not connected</source>
        <translation>bazı sunucular bağlı değil</translation>
    </message>
    <message>
        <source>Form</source>
        <translation>Form</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>logo</translation>
    </message>
    <message>
        <source>minimize</source>
        <translation>küçült</translation>
    </message>
    <message>
        <source>close</source>
        <translation>kapat</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>Seç</translation>
    </message>
    <message>
        <source>brand</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>or Drop Folder to Sync</source>
        <translation>ya da Sürükle</translation>
    </message>
    <message>
        <source>download rate</source>
        <translation>indirme oranı</translation>
    </message>
    <message>
        <source>downarrow</source>
        <translation>aşağı ok</translation>
    </message>
    <message>
        <source>upload rate</source>
        <translation>yükleme oranı</translation>
    </message>
    <message>
        <source>uparrow</source>
        <translation>yukarı ok</translation>
    </message>
</context>
<context>
    <name>Configurator</name>
    <message>
        <source>Error when creating ccnet configuration</source>
        <translation>ccnet konfigürasyonu oluşturulurken hata </translation>
    </message>
    <message>
        <source>Unable to create preconfigure directory &quot;%1&quot;</source>
        <translation>Ön yapılandırma dizini &quot;%1&quot; oluşturulamıyor
</translation>
    </message>
    <message>
        <source>failed to read %1</source>
        <translation>okuma başarısız %1 </translation>
    </message>
</context>
<context>
    <name>CreateRepoDialog</name>
    <message>
        <source>Create a library</source>
        <translation>Bir kütüphane oluştur</translation>
    </message>
    <message>
        <source>Please choose a directory</source>
        <translation>Lütfen bir dizin seçin</translation>
    </message>
    <message>
        <source>Creating...</source>
        <translation>Oluşturuyor...</translation>
    </message>
    <message>
        <source>Failed to generate encryption key for this library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please choose the directory to sync</source>
        <translation>Lütfen senkronize edilecek dizini seçin</translation>
    </message>
    <message>
        <source>The folder %1 does not exist</source>
        <translation>Klasör %1 yok</translation>
    </message>
    <message>
        <source>Please enter the name</source>
        <translation>Lütfen isim giriniz</translation>
    </message>
    <message>
        <source>Please enter the password</source>
        <translation>Lütfen şifreyi giriniz</translation>
    </message>
    <message>
        <source>Passwords don&apos;t match</source>
        <translation>Şifreler eşleşmiyor</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Bilinmeyen hata</translation>
    </message>
    <message>
        <source>Failed to add download task:
 %1</source>
        <translation>İndirme görevi ekleme başarısız:
 %1</translation>
    </message>
    <message>
        <source>Failed to create library on the server:
%1</source>
        <translation>Sunucuda kütüphane oluşturma başarısız:
%1</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Path:</source>
        <translation>Yol:</translation>
    </message>
    <message>
        <source>Choose</source>
        <translation>Seç</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>İsim:</translation>
    </message>
    <message>
        <source>encrypted</source>
        <translation>şifreli</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Şifre:</translation>
    </message>
    <message>
        <source>Password Again:</source>
        <translation>Şifre Tekrar:</translation>
    </message>
    <message>
        <source>status text</source>
        <translation>durum metni</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Tamam</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal et</translation>
    </message>
</context>
<context>
    <name>DaemonManager</name>
    <message>
        <source>failed to load ccnet config dir %1</source>
        <translation> ccnet config dir %1 yükleme başarısız</translation>
    </message>
    <message>
        <source>%1 client failed to initialize</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DownloadRepoDialog</name>
    <message>
        <source>Please enter the password</source>
        <translation>Lütfen şifreyi girin</translation>
    </message>
    <message>
        <source>Sync library &quot;%1&quot;</source>
        <translation>Kütüphaneyi Senkronize et &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Sync folder &quot;%1&quot;</source>
        <translation>Senkronizasyon klasörü &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Sync to folder:</source>
        <translation>Klasöre senkronize et:</translation>
    </message>
    <message>
        <source>or</source>
        <translation>ya da</translation>
    </message>
    <message>
        <source>sync with an existing folder</source>
        <translation>mevcut bir klasörle senkronize et</translation>
    </message>
    <message>
        <source>create a new sync folder</source>
        <translation>yeni bir senkronizasyon klasörü oluştur</translation>
    </message>
    <message>
        <source>Sync with this existing folder:</source>
        <translation>Bu mevcut klasörle senkronize et:</translation>
    </message>
    <message>
        <source>Please choose a folder</source>
        <translation>Lütfen bir klasör seçin</translation>
    </message>
    <message>
        <source>The folder does not exist</source>
        <translation>Klasör mevcut değil</translation>
    </message>
    <message>
        <source>Please choose the folder to sync.</source>
        <translation>Lütfen senkronize edilecek klasörü seçin.</translation>
    </message>
    <message>
        <source>Your organization disables putting a library outside %1 folder.</source>
        <translation>Organizasyonunuz %1 klasörü dışına kütüphane koyulmasını engelliyor.</translation>
    </message>
    <message>
        <source>Conflicting with existing file &quot;%1&quot;, please choose a different folder.</source>
        <translation>Mevcut &quot;%1&quot; dosyası ile uyuşmazlık var, lütfen başka bir klasör seçin.</translation>
    </message>
    <message>
        <source>Conflicting with existing library &quot;%1&quot;, please choose a different folder.</source>
        <translation>Mevcut &quot;%1&quot; kütüphanesi ile uyuşmazlık var, lütfen başka bir klasör seçin.</translation>
    </message>
    <message>
        <source>The folder &quot;%1&quot; already exists. Are you sure to sync with it (contents will be merged)?</source>
        <translation>&quot;%1&quot; klasörü zaten var. Onunla senkronize etmek istediğinize emin misiniz (içerikler birleştirilecek)?</translation>
    </message>
    <message>
        <source>Click No to sync with a new folder instead</source>
        <translation>Yeni bir klasörle senkronize etmek için Hayır&apos;ı tıklayın</translation>
    </message>
    <message>
        <source>Unable to find an alternative folder name</source>
        <translation>Alternatif bir klasör ismi bulunamıyor</translation>
    </message>
    <message>
        <source>Failed to add download task:
 %1</source>
        <translation>İndirme görevi ekleme başarısız:
 %1</translation>
    </message>
    <message>
        <source>Failed to get repo download information:
%1</source>
        <translation>Repo indirme bilgisi alınamadı:
%1</translation>
    </message>
    <message>
        <source>Download Library</source>
        <translation>Kütüphaneyi İndir</translation>
    </message>
    <message>
        <source>choose...</source>
        <translation>seç...</translation>
    </message>
    <message>
        <source>Password for this library:</source>
        <translation>Bu kütüphane için şifre:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Tamam</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal Et</translation>
    </message>
</context>
<context>
    <name>EventDetailsDialog</name>
    <message>
        <source>Modification Details</source>
        <translation>Değiştirme Ayrıntıları</translation>
    </message>
</context>
<context>
    <name>EventDetailsListModel</name>
    <message>
        <source>Added files</source>
        <translation>Eklenen dosyalar</translation>
    </message>
    <message>
        <source>Deleted files</source>
        <translation>Silinen dosyalar</translation>
    </message>
    <message>
        <source>Modified files</source>
        <translation>Değiştirilen dosyalar</translation>
    </message>
    <message>
        <source>Added folders</source>
        <translation>Eklenen klasörler</translation>
    </message>
    <message>
        <source>Deleted folders</source>
        <translation>Silinen klasörler</translation>
    </message>
</context>
<context>
    <name>EventDetailsListView</name>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Aç</translation>
    </message>
    <message>
        <source>Open &amp;parent folder</source>
        <translation>Aç &amp;ebeveyn klasör</translation>
    </message>
</context>
<context>
    <name>FileBrowserDialog</name>
    <message>
        <source>Cloud File Browser</source>
        <translation>Bulut Dosya Tarayıcısı</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Geri</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>İlet</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Anasayfa</translation>
    </message>
    <message>
        <source>Upload files</source>
        <translation>Dosyaları yükle</translation>
    </message>
    <message>
        <source>Upload a directory</source>
        <translation>Bir dizin yükle</translation>
    </message>
    <message>
        <source>You don&apos;t have permission to upload files to this library</source>
        <translation>Bu kütüphaneye dosya yüklemek için izniniz yok</translation>
    </message>
    <message>
        <source>Create a folder</source>
        <translation>Bir klasör oluşturun</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 items</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Folder name</source>
        <translation>Klasör adı </translation>
    </message>
    <message>
        <source>Invalid folder name!</source>
        <translation>Geçersiz klasör adı!</translation>
    </message>
    <message>
        <source>The name &quot;%1&quot; is already taken.</source>
        <translation>&quot;%1&quot; ismi daha önce alınmış.</translation>
    </message>
    <message>
        <source>retry</source>
        <translation>tekrar deneyin</translation>
    </message>
    <message>
        <source>Failed to get files information&lt;br/&gt;Please %1</source>
        <translation>Dosya bilgileri alınamadı&lt;br/&gt;Lütfen %1</translation>
    </message>
    <message>
        <source>This folder is empty.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enter name of file to save to...</source>
        <translation>Kaydetmek için dosya adını girin</translation>
    </message>
    <message>
        <source>Unable to remove file &quot;%1&quot;</source>
        <translation>&quot;%1&quot; dosyası kaldırılamıyor</translation>
    </message>
    <message>
        <source>Enter the path of the folder you want to save to...</source>
        <translation>Kaydetmek istediğiniz klasör yolunu girin...</translation>
    </message>
    <message>
        <source>Do you want to overwrite the existing file &quot;%1&quot;?</source>
        <translation>&quot;%1&quot; dosyasının üzerine yazmak istiyor musunuz?</translation>
    </message>
    <message>
        <source>File &quot;%1&quot; haven&apos;t been synced</source>
        <translation>&quot;%1&quot; dosyası senkronize edilmedi</translation>
    </message>
    <message>
        <source>File %1 already exists.&lt;br/&gt;Do you like to overwrite it?&lt;br/&gt;&lt;small&gt;(Choose No to upload using an alternative name).&lt;/small&gt;</source>
        <translation>Dosya %1 zaten var.&lt;br/&gt;Üstüne yazmak ister misiniz?&lt;br/&gt;&lt;small&gt;(Başka bir isim kullanarak yüklemek için Hayır seçin).&lt;/small&gt;</translation>
    </message>
    <message>
        <source>File does not exist</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to download file: %1</source>
        <translation>Dosya indirme başarısız: %1</translation>
    </message>
    <message>
        <source>Select a file to upload</source>
        <translation>Yüklemek için bir dosya seçin</translation>
    </message>
    <message>
        <source>Select a directory to upload</source>
        <translation>Yüklemek için bir dizin seçin</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Yeniden adlandır</translation>
    </message>
    <message>
        <source>Do you really want to delete these items</source>
        <translation>Bu öğeleri silmeyi gerçekten istiyor musunuz?</translation>
    </message>
    <message>
        <source>Create folder failed</source>
        <translation>Klasör oluşturma başarısız</translation>
    </message>
    <message>
        <source>Lock file failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Select a file to update %1</source>
        <translation>Güncellemek için bir dosya seç %1</translation>
    </message>
    <message>
        <source>Rename failed</source>
        <translation>Yeniden adlandırılamadı</translation>
    </message>
    <message>
        <source>Remove failed</source>
        <translation>Taşıma başarısız</translation>
    </message>
    <message>
        <source>Share failed</source>
        <translation>Paylaşma başarısız</translation>
    </message>
    <message>
        <source>Cannot paste files from the same folder</source>
        <translation>Aynı klasörden dosyalar yapıştırılamaz</translation>
    </message>
    <message>
        <source>Cannot paste the folder to its subfolder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Copy failed</source>
        <translation>Kopyalama başarısız</translation>
    </message>
    <message>
        <source>Move failed</source>
        <translation>Taşıma başarısız</translation>
    </message>
    <message>
        <source>Create library failed!</source>
        <translation>Kütüphane oluşturma başarısız!</translation>
    </message>
    <message>
        <source>You do not have permission to upload to this folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Authorization expired</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Permission Error!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library/Folder not found.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to upload file %1: %2</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to create cache folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to open cache folder</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileBrowserProgressDialog</name>
    <message>
        <source>Pending</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal et</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Yükle</translation>
    </message>
    <message>
        <source>Uploading %1</source>
        <translation>Yüklüyor %1</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>İndir</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>İndiriyor %1</translation>
    </message>
    <message>
        <source>%1 of %2</source>
        <translation>%2 de %1</translation>
    </message>
    <message>
        <source>Failed to upload file &quot;%1&quot;, do you want to retry?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Retry</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Skip</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Abort</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileNetworkTask</name>
    <message>
        <source>Operation canceled</source>
        <translation>İşlem iptal edildi.</translation>
    </message>
    <message>
        <source>pending</source>
        <translation>beklemede</translation>
    </message>
</context>
<context>
    <name>FileServerTask</name>
    <message>
        <source>task cancelled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internal Server Error</source>
        <translation>İç Sunucu Hatası</translation>
    </message>
    <message>
        <source>The storage quota has been used up</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileTableModel</name>
    <message>
        <source>locked by %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Name</source>
        <translation>İsim</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Boyut</translation>
    </message>
    <message>
        <source>Last Modified</source>
        <translation>En son Değiştirme</translation>
    </message>
    <message>
        <source>Kind</source>
        <translation>Tür</translation>
    </message>
</context>
<context>
    <name>FileTableView</name>
    <message>
        <source>&amp;Save As...</source>
        <translation>&amp;Farklı kaydet</translation>
    </message>
    <message>
        <source>&amp;Lock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Rename</source>
        <translation>&amp;Yeniden Adlandır</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Sil</translation>
    </message>
    <message>
        <source>Share to Group</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Update</source>
        <translation>&amp;Güncelle</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopyala</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>&amp;Kes</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>&amp;Yapıştır</translation>
    </message>
    <message>
        <source>Canc&amp;el Download</source>
        <translation>&amp;İndirmeyi iptal et</translation>
    </message>
    <message>
        <source>&amp;Sync this folder</source>
        <translation>&amp;Bu klasörü senkronize et</translation>
    </message>
    <message>
        <source>This feature is available in pro version only
</source>
        <translation>Bu özellik sadece pro versiyonda mevcut</translation>
    </message>
    <message>
        <source>&amp;Generate %1 Download Link</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share to User</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>G&amp;enerate %1 Internal Link</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Save As To...</source>
        <translation>&amp;Buraya farklı kaydet...</translation>
    </message>
    <message>
        <source>Un&amp;lock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to remove readonly files</source>
        <translation>Salt okunur dosyalar kaldırılamıyor</translation>
    </message>
    <message>
        <source>Unable to cut readonly files</source>
        <translation>Salt okunur dosyalar kesilemiyor</translation>
    </message>
    <message>
        <source>Retry Upload</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete Local Version</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Local Version Save As...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open Local Cache Folder</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GetFileTask</name>
    <message>
        <source>Failed to create folders</source>
        <translation>Klasör oluşturma başarısız</translation>
    </message>
    <message>
        <source>Failed to create temporary files</source>
        <translation>Geçici dosya oluşturma başarısız</translation>
    </message>
    <message>
        <source>Failed to write file to disk</source>
        <translation>Dosyayı diske yazma başarısız</translation>
    </message>
    <message>
        <source>Failed to remove the older version of the downloaded file</source>
        <translation>İndirilen dosyanın eski versiyonu kaldırılamadı</translation>
    </message>
    <message>
        <source>Failed to move file</source>
        <translation>Dosya kaldırılamadı</translation>
    </message>
</context>
<context>
    <name>InitSeafileDialog</name>
    <message>
        <source>%1 Initialization</source>
        <translation>%1 başlatma</translation>
    </message>
    <message>
        <source>Choose %1 folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please choose a directory</source>
        <translation>Lütfen bir dizin seçin</translation>
    </message>
    <message>
        <source>Initialization is not finished. Really quit?</source>
        <translation>Başlatma henüz bitmedi. Gerçekten çıkıyor musunuz?</translation>
    </message>
    <message>
        <source>The folder %1 does not exist</source>
        <translation>Klasör %1 yok</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>logo</translation>
    </message>
    <message>
        <source>Choose a folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please choose a folder. We will create a %1 subfolder in it. When you download a library, it will be saved there by default.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Choose...</source>
        <translation>Seç...</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Sonraki</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal et</translation>
    </message>
</context>
<context>
    <name>InitVirtualDriveDialog</name>
    <message>
        <source>%1 organizes files by libraries.
Do you like to download your default library?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Checking your default library...</source>
        <translation>Varsayılan kütüphanenizi kontrol ediyor...</translation>
    </message>
    <message>
        <source>Creating the default library...</source>
        <translation>Varsayılan kütüphane oluşturuluyor...</translation>
    </message>
    <message>
        <source>Failed to create default library:

The server version must be 2.1 or higher to support this.</source>
        <translation>Varsayılan kütüphane oluşturma başarısız:

Bu işlemin desteklenmesi için Sunucu versiyonu 2.1 ya da daha yüksek olmalı.</translation>
    </message>
    <message>
        <source>Failed to get default library:
%1</source>
        <translation>Varsayılan kütüphaneyi alma başarısız:
%1</translation>
    </message>
    <message>
        <source>Failed to create default library:
%1</source>
        <translation>Varsayılan kütüphane oluşturma başarısız:
%1</translation>
    </message>
    <message>
        <source>Downloading default library...</source>
        <translation>Varsayılan kütüphane indiriliyor...</translation>
    </message>
    <message>
        <source>Failed to download default library:
%1</source>
        <translation>Varsayılan kütüphaneyi indirme başarısız:
%1</translation>
    </message>
    <message>
        <source>The default library has been downloaded.
You can click the &quot;Open&quot; button to view it.</source>
        <translation>Varsayılan kütüphane indirildi.
Görüntülemek için &quot;Aç&quot; düğmesine basabilirsiniz.</translation>
    </message>
    <message>
        <source>Error when downloading the default library: %1</source>
        <translation>Varsayılan kütüphane indirilirken hata oluştu: %1</translation>
    </message>
    <message>
        <source>Failed to download default library:
 %1</source>
        <translation>Varsayılan kütüphaneyi indirme başarısız oldu:
 %1</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>%1 organizes files by libraries. 
Do you like to download your default library?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Skip</source>
        <translation>Atla</translation>
    </message>
    <message>
        <source>Run in Background</source>
        <translation>Arka planda yürüt</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Aç</translation>
    </message>
    <message>
        <source>Finish</source>
        <translation>Son</translation>
    </message>
    <message>
        <source>Download Default Library</source>
        <translation>Varsayılan Kütüphaneyi İndir</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Evet</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>logo</translation>
    </message>
</context>
<context>
    <name>LoadMoreButton</name>
    <message>
        <source>load more</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LoginDialog</name>
    <message>
        <source>Add an account</source>
        <translation>Hesap ekle</translation>
    </message>
    <message>
        <source>Single Sign On</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Re-login</source>
        <translation>yeniden giriş yapın</translation>
    </message>
    <message>
        <source>Logging in...</source>
        <translation>Giriş yapıyor...</translation>
    </message>
    <message>
        <source>Network Error:
 %1</source>
        <translation>Ağ Hatası:
 %1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Warning:&lt;/b&gt; The ssl certificate of this server is not trusted, proceed anyway?</source>
        <translation>&lt;b&gt;Uyarı:&lt;/b&gt; Bu sunucunun ssl sertifikası güvenilir değil, yine de devam edilsin mi?</translation>
    </message>
    <message>
        <source>Please enter the server address</source>
        <translation>Lütfen sunucu adresini giriniz</translation>
    </message>
    <message>
        <source>%1 is not a valid server address</source>
        <translation>%1 geçerli bir sunucu adresi değil</translation>
    </message>
    <message>
        <source>Please enter the username</source>
        <translation>lütfen kullanıcı adını giriniz</translation>
    </message>
    <message>
        <source>Please enter the computer name</source>
        <translation>Lütfen bilgisayar adını giriniz</translation>
    </message>
    <message>
        <source>Failed to save current account</source>
        <translation>Mevcut hesabı kaydetme başarısız</translation>
    </message>
    <message>
        <source>Two Factor Authentication</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 Server Address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Server address must not be empty</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 is not a valid server address. It has to start with &apos;https://&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please enter the password</source>
        <translation>Lütfen şifreyi giriniz</translation>
    </message>
    <message>
        <source>Enter the two factor authentication token</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Incorrect email or password</source>
        <translation>Hatalı eposta ya da şifre</translation>
    </message>
    <message>
        <source>Logging in too frequently, please wait a minute</source>
        <translation>Çok sık giriş yapılıyor, lütfen bir dakika bekleyin</translation>
    </message>
    <message>
        <source>Internal Server Error</source>
        <translation>İç Sunucu Hatası</translation>
    </message>
    <message>
        <source>Failed to login: %1</source>
        <translation>Giriş yapılamadı: %1</translation>
    </message>
    <message>
        <source>Failed to login</source>
        <translation>Giriş yapılamadı</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>logo</translation>
    </message>
    <message>
        <source>Server:</source>
        <translation>Sunucu:</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;For example: https://seacloud.cc&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Örneğin: https://seacloud.cc&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>or http://192.168.1.24:8000</source>
        <translation>or http://192.168.1.24:8000</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Şifre:</translation>
    </message>
    <message>
        <source>status text</source>
        <translation>durum metini</translation>
    </message>
    <message>
        <source>Computer Name:</source>
        <translation>Bilgisayar Adı:</translation>
    </message>
    <message>
        <source>Email / Username:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>e.g. Jim&apos;s laptop</source>
        <translation>örnek: Can&apos;ın bilgisayarı</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Giriş</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal et</translation>
    </message>
</context>
<context>
    <name>LogoutView</name>
    <message>
        <source>You are logout. Please </source>
        <translation>Çıkış yaptınız. Lütfen</translation>
    </message>
    <message>
        <source>login</source>
        <translation>giriş yap</translation>
    </message>
    <message>
        <source>Add an account</source>
        <translation>Hesap ekle</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Refresh</source>
        <translation>Yenile</translation>
    </message>
</context>
<context>
    <name>MessageListener</name>
    <message>
        <source>failed to load ccnet config dir </source>
        <translation>ccnet config dir yüklenemedi</translation>
    </message>
    <message>
        <source>&quot;%1&quot; is unsynced. 
Reason: Deleted on server</source>
        <translation>&quot;%1&quot; senkronizasyon sonlandırıldı. 
Nedeni: Sunucuda silindi</translation>
    </message>
    <message>
        <source>&quot;%1&quot; is synchronized</source>
        <translation>&quot;%1&quot; senkronize edildi</translation>
    </message>
    <message>
        <source>Files uploaded to &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File %1 conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to sync file %1
File is locked by other application. This file will be updated when you close the application.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to sync folder %1
Some file in this folder is locked by other application. This folder will be updated when you close the application.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to sync file %1
File is locked by other user on the server. Update to this file is not uploaded.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to sync %1
File path is ended with space or period and cannot be created on Windows.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to sync %1
File path contains invalid characters. It is not synced to this computer.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to index file %1
Please check file permission and disk space.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&quot;%1&quot; failed to sync. 
Access denied to service</source>
        <translation>&quot;%1&quot; senkronizasyon başarısız. 
Servise erişim reddedildi</translation>
    </message>
    <message>
        <source>&quot;%1&quot; failed to sync.
The library owner&apos;s storage space is used up.</source>
        <translation>&quot;%1&quot; senkronizasyon başarısız.
Kütüphane sahibinin depolama alanı tükendi.</translation>
    </message>
</context>
<context>
    <name>PrivateShareDialog</name>
    <message>
        <source>Share %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enter the group name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enter user name or email address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Updated successfully</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share Operation Failed: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Removed successfully</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to get share information of the folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to get your groups and contacts information</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please enter the username</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please enter the group name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No such group &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Already shared to group %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Already shared to user %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The previous operation is still in progres</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dialog</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share To:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Permission:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Read-Write</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Read-Only</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>synchronized</source>
        <translation>senkronize</translation>
    </message>
    <message>
        <source>indexing files</source>
        <translation>dosyaları indeksliyor</translation>
    </message>
    <message>
        <source>sync initializing</source>
        <translation>senkronizasyon başlatılıyor</translation>
    </message>
    <message>
        <source>downloading</source>
        <translation>indiriyor</translation>
    </message>
    <message>
        <source>uploading</source>
        <translation>yüklüyor</translation>
    </message>
    <message>
        <source>sync merging</source>
        <translation>senkronizasyon birleştirme</translation>
    </message>
    <message>
        <source>waiting for sync</source>
        <translation>senkronizasyon için bekliyor</translation>
    </message>
    <message>
        <source>server not connected</source>
        <translation>sunucu bağlı deği</translation>
    </message>
    <message>
        <source>server authenticating</source>
        <translation>sunucu kimliği doğrulanıyor</translation>
    </message>
    <message>
        <source>auto sync is turned off</source>
        <translation>oto senkronizasyon kapatıldı</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>bilinmeyen</translation>
    </message>
    <message>
        <source>Server has been removed</source>
        <translation>Sunucu kaldırıldı</translation>
    </message>
    <message>
        <source>You have not logged in to the server</source>
        <translation>Sunucuya giriş yapmadınız</translation>
    </message>
    <message>
        <source>You do not have permission to access this library</source>
        <translation>Bu kütüphaneye erişim izniniz yok</translation>
    </message>
    <message>
        <source>The storage space of the library owner has been used up</source>
        <translation>Kütüphane sahibinin depolama alanı tükendi.</translation>
    </message>
    <message>
        <source>Remote service is not available</source>
        <translation>Uzaktan hizmet kullanılamıyor</translation>
    </message>
    <message>
        <source>Access denied to service</source>
        <translation>Servise erişim reddildi</translation>
    </message>
    <message>
        <source>Internal data corrupted</source>
        <translation>İç veri bozuk</translation>
    </message>
    <message>
        <source>Failed to start upload</source>
        <translation>Yükleme başlatılamadı</translation>
    </message>
    <message>
        <source>Error occured in upload</source>
        <translation>Yüklemede hata oluştu</translation>
    </message>
    <message>
        <source>Failed to start download</source>
        <translation>İndirme başlatılamadı</translation>
    </message>
    <message>
        <source>Error occured in download</source>
        <translation>İndirmede hata oluştu</translation>
    </message>
    <message>
        <source>Library is damaged on server</source>
        <translation>Kütüphane sunucuda hasar gördü</translation>
    </message>
    <message>
        <source>Conflict in merge</source>
        <translation>Birleştirmede uyuşmazlık</translation>
    </message>
    <message>
        <source>Server version is too old</source>
        <translation>Sunucu versiyonu çok eski</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Bilinmeyen hata</translation>
    </message>
    <message>
        <source>Permission denied on server. Please try resync the library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Network error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cannot resolve proxy address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cannot resolve server address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cannot connect to server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to establish secure connection. Please check server SSL certificate</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Data transfer was interrupted. Please check network or firewall</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Data transfer timed out. Please check network or firewall</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unhandled http redirect from server. Please check server cofiguration</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Server error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Bad request</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internal data corrupt on the client. Please try resync the library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Not enough memory</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to write data on the client. Please check disk space or folder permissions</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Storage quota full</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library deleted on server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library damaged on server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The storage quota has been used up</source>
        <translation>Depolama kotası tükendi</translation>
    </message>
    <message>
        <source>Internal server error</source>
        <translation>İç sunucu hatası</translation>
    </message>
    <message>
        <source>Your %1 client is too old</source>
        <translation>%1 istemciniz çok eski</translation>
    </message>
    <message>
        <source>Failed to sync this library</source>
        <translation>Kütüphane senkronizasyonu başarısız oldu</translation>
    </message>
    <message>
        <source>Files are locked by other application</source>
        <translation>Dosyalar bir başka uygulama tarafından kilitlendi</translation>
    </message>
    <message>
        <source>Library is deleted on server</source>
        <translation>Kütüphane sunucuda silindi</translation>
    </message>
    <message>
        <source>Error when accessing the local folder</source>
        <translation>Lokal dosyaya erişim hatası</translation>
    </message>
    <message>
        <source>initializing...</source>
        <translation>başlatılıyor...</translation>
    </message>
    <message>
        <source>Failed to index local files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to check server information</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to create local files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to merge local file changes</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Incorrect password. Please download again</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internal error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>connecting server...</source>
        <translation>sunucuya bağlanıyor...</translation>
    </message>
    <message>
        <source>indexing files...</source>
        <translation>dosyalar indeksleniyor...</translation>
    </message>
    <message>
        <source>Downloading file list...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloading files...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Creating folder...</source>
        <translation>Dosya oluşturuyor...</translation>
    </message>
    <message>
        <source>Merge file changes...</source>
        <translation>Dosya değişikliklerini birleştiriyor...</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Tamam</translation>
    </message>
    <message>
        <source>checking server info...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Canceling</source>
        <translation>İptal ediyor</translation>
    </message>
    <message>
        <source>Canceled</source>
        <translation>İptal edildi</translation>
    </message>
    <message>
        <source>SSL Error</source>
        <translation>SSL Hatası</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>Ağ Hatası: %1</translation>
    </message>
    <message>
        <source>Server Error</source>
        <translation>Sunucu Hatası</translation>
    </message>
    <message>
        <source>failed to open certs database</source>
        <translation>Veritabanı sertifikası açılamadı</translation>
    </message>
    <message>
        <source>File &quot;%1&quot; doesn&apos;t exist in &quot;%2&quot;</source>
        <translation> &quot;%2&quot;&apos;de dosya &quot;%1&quot; mevcut değil</translation>
    </message>
    <message>
        <source>%1 couldn&apos;t find an application to open file %2</source>
        <translation>%1  %2 dosyasını açmak için uygulama bulamadı.</translation>
    </message>
    <message>
        <source>Created library &quot;%1&quot;</source>
        <translation>&quot;%1&quot; kütüphanesini oluştur.</translation>
    </message>
    <message>
        <source>Deleted library &quot;%1&quot;</source>
        <translation>&quot;%1&quot; silinmiş kütüphane</translation>
    </message>
    <message>
        <source>Rename %1 to</source>
        <translation>%1&apos;i Yeniden adlandır </translation>
    </message>
    <message>
        <source>Unable to download item &quot;%1&quot;</source>
        <translation>&quot;%1&quot; öğesi indirilemedi</translation>
    </message>
    <message>
        <source>copy failed</source>
        <translation>kopyalama başarısız</translation>
    </message>
    <message>
        <source>Added</source>
        <translation>Eklendi</translation>
    </message>
    <message>
        <source>Deleted</source>
        <translation>Silindi</translation>
    </message>
    <message>
        <source>Removed</source>
        <translation>Kaldırıldı</translation>
    </message>
    <message>
        <source>Modified</source>
        <translation>Değiştirildi</translation>
    </message>
    <message>
        <source>Renamed</source>
        <translation>Yeniden adlandırıldı</translation>
    </message>
    <message>
        <source>Added or modified</source>
        <translation>Eklendi ya da değiştirildi</translation>
    </message>
    <message>
        <source>Moved</source>
        <translation>Taşındı</translation>
    </message>
    <message>
        <source>Added directory</source>
        <translation>Eklenen dizin</translation>
    </message>
    <message>
        <source>Removed directory</source>
        <translation>Kaldırılan dizin</translation>
    </message>
    <message>
        <source>Renamed directory</source>
        <translation>Yeniden adlandırılan dizin</translation>
    </message>
    <message>
        <source>Moved directory</source>
        <translation>Taşınan dizin</translation>
    </message>
    <message>
        <source>files</source>
        <translation>dosyalar</translation>
    </message>
    <message>
        <source>directories</source>
        <translation>dizinler</translation>
    </message>
    <message>
        <source>and %1 more</source>
        <translation>ve %1 tane daha</translation>
    </message>
    <message>
        <source>Reverted library to status at</source>
        <translation>Şu duruma geri çevrilmiş kütüphane</translation>
    </message>
    <message>
        <source>Reverted file &quot;%1&quot; to status at %2.</source>
        <translation>%2 durumuna çevrilmiş &quot;%1&quot; dosyası</translation>
    </message>
    <message>
        <source>Recovered deleted directory</source>
        <translation>Kurtarılan silinmiş kütüphane</translation>
    </message>
    <message>
        <source>Changed library name or description</source>
        <translation>Değiştirilmiş kütüphane adı ya da açıklaması</translation>
    </message>
    <message>
        <source>Auto merge by %1 system</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Just now</source>
        <translation>Hemen şimdi</translation>
    </message>
    <message>
        <source>1 day ago</source>
        <translation>1 gün önce</translation>
    </message>
    <message>
        <source>%1 days ago</source>
        <translation>%1 gün önce</translation>
    </message>
    <message>
        <source>1 hour ago</source>
        <translation>1 saat önce</translation>
    </message>
    <message>
        <source>%1 hours ago</source>
        <translation>%1 saat önce</translation>
    </message>
    <message>
        <source>1 minute ago</source>
        <translation> 1 dakika önce</translation>
    </message>
    <message>
        <source>%1 minutes ago</source>
        <translation>%1 dakika önce</translation>
    </message>
    <message>
        <source>&lt;Not Part of Certificate&gt;</source>
        <translation>&lt;Not Part of Certificate&gt;</translation>
    </message>
    <message>
        <source>Found another running process of %1, kill it and start a new one?</source>
        <translation>Yürümekte olan bir başka %1 işlemini bul, durdur ve yeni bir tane başlat?</translation>
    </message>
    <message>
        <source>Unable to start %1 due to the failure of shutting down the previous process</source>
        <translation>Önceki işlem kapatılamadığı için %1 başlatılamıyor</translation>
    </message>
    <message>
        <source>Sync this library to:</source>
        <translation>Bu kütüphaneyi şuraya eşitle:</translation>
    </message>
    <message>
        <source>Sync this folder to:</source>
        <translation>Bu klasörü şuraya eşitle:</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Klasör</translation>
    </message>
    <message>
        <source>Readonly Folder</source>
        <translation>Salt okunur Klasör</translation>
    </message>
    <message>
        <source>Document</source>
        <translation>Doküman</translation>
    </message>
    <message>
        <source>PDF Document</source>
        <translation>PDF Dokümanı</translation>
    </message>
    <message>
        <source>Image File</source>
        <translation>İmaj dosyası</translation>
    </message>
    <message>
        <source>Text Document</source>
        <translation>Text Dokümanı</translation>
    </message>
    <message>
        <source>Audio File</source>
        <translation>Ses Dosyası</translation>
    </message>
    <message>
        <source>Video File</source>
        <translation>Video Dosyası</translation>
    </message>
    <message>
        <source>Word Document</source>
        <translation>Word Dokümanı</translation>
    </message>
    <message>
        <source>PowerPoint Document</source>
        <translation>PowerPoint Dokümanı</translation>
    </message>
    <message>
        <source>Excel Document</source>
        <translation>Excel Dokümanı</translation>
    </message>
    <message>
        <source>The path &quot;%1&quot; conflicts with system path</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The path &quot;%1&quot; conflicts with an existing library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>uploading file list</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File is locked by another application</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Folder is locked by another application</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File is locked by another user</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Path is invalid</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Error when indexing</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Path ends with space or period character</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Path contains invalid characters like &apos;|&apos; or &apos;:&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>failed to open file cache database</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library name contains invalid characters such as &apos;:&apos;, &apos;*&apos;, &apos;|&apos;, &apos;?&apos;</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ReliablePostFileTask</name>
    <message>
        <source>File does not exist</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RepoDetailDialog</name>
    <message>
        <source>Library &quot;%1&quot;</source>
        <translation>Kütüphane &quot;%1&quot;</translation>
    </message>
    <message>
        <source>This library is not downloaded yet</source>
        <translation>Bu kütüphane henüz indirilmedi</translation>
    </message>
    <message>
        <source>Error: </source>
        <translation>Hata:</translation>
    </message>
    <message>
        <source>every %1 seconds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>RepoIcon</source>
        <translation>RepoSimgesi</translation>
    </message>
    <message>
        <source>RepoName</source>
        <translation>RepoAdı</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Açıklama</translation>
    </message>
    <message>
        <source>TextLabel</source>
        <translation>MetinEtiketi</translation>
    </message>
    <message>
        <source>Owner:</source>
        <translation>Sahip:</translation>
    </message>
    <message>
        <source>Last Modified:</source>
        <translation>En son Değiştirme:</translation>
    </message>
    <message>
        <source>mtime</source>
        <translation>mtime</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Boyut:</translation>
    </message>
    <message>
        <source>Local Path:</source>
        <translation>Lokal Yol:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Durum:</translation>
    </message>
    <message>
        <source>RepoStatus</source>
        <translation>RepoDurumu</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>İsim:</translation>
    </message>
    <message>
        <source>Sync Interval:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
</context>
<context>
    <name>RepoItemDelegate</name>
    <message>
        <source>, %1%2</source>
        <translation>, %1%2</translation>
    </message>
    <message>
        <source>, %1</source>
        <translation>, %1</translation>
    </message>
    <message>
        <source>This library has not been downloaded</source>
        <translation>Bu kütüphane henüz indirilmedi</translation>
    </message>
</context>
<context>
    <name>RepoService</name>
    <message>
        <source>Unable to open file &quot;%1&quot; from nonexistent library &quot;%2&quot;</source>
        <translation>Varolmayan &quot;%2&quot; kütüphanesinden &quot;%1&quot; dosyası açılamıyor</translation>
    </message>
</context>
<context>
    <name>RepoTreeModel</name>
    <message>
        <source>Recently Updated</source>
        <translation>Yeni Güncellenen</translation>
    </message>
    <message>
        <source>My Libraries</source>
        <translation>Kütüphanelerim</translation>
    </message>
    <message>
        <source>Sub Libraries</source>
        <translation>Alt Kütüphaneler</translation>
    </message>
    <message>
        <source>Shared with me</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shared with all</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shared with groups</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Synced Libraries</source>
        <translation>Senkronize Kütüphaneler</translation>
    </message>
    <message>
        <source>sync initializing</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RepoTreeView</name>
    <message>
        <source>Disable auto sync</source>
        <translation>Oto senkronizasyonu devre dışı bırak</translation>
    </message>
    <message>
        <source>Enable auto sync</source>
        <translation>Oto senkronizasyonu etkinleştir</translation>
    </message>
    <message>
        <source>Show &amp;details</source>
        <translation>Göster &amp;ayrıntılar</translation>
    </message>
    <message>
        <source>Show details of this library</source>
        <translation>Bu kütüphanenin ayrıntılarını göster</translation>
    </message>
    <message>
        <source>&amp;Sync this library</source>
        <translation>&amp;Bu kütüphaneyi senkronize et</translation>
    </message>
    <message>
        <source>Sync this library</source>
        <translation>Bu kütüphaneyi senkronize et</translation>
    </message>
    <message>
        <source>Recently Updated</source>
        <translation>Yeni Güncellenen</translation>
    </message>
    <message>
        <source>Sync &amp;now</source>
        <translation>Eşitle &amp;şimdi</translation>
    </message>
    <message>
        <source>Sync this library immediately</source>
        <translation>Bu kütüphaneyi hemen senkronize et</translation>
    </message>
    <message>
        <source>&amp;Cancel download</source>
        <translation>&amp;İptal et indirme</translation>
    </message>
    <message>
        <source>Cancel download of this library</source>
        <translation>Bu kütüphaneyi indirmeyi iptal et</translation>
    </message>
    <message>
        <source>&amp;Open folder</source>
        <translation>Dosyayı &amp;Aç </translation>
    </message>
    <message>
        <source>open local folder</source>
        <translation>lokal dosya aç</translation>
    </message>
    <message>
        <source>&amp;Open local folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Unsync</source>
        <translation>&amp;Senkronizasyonu sonlandır</translation>
    </message>
    <message>
        <source>unsync this library</source>
        <translation>Bu kütüphane senkronizasyonunu sonlandır</translation>
    </message>
    <message>
        <source>&amp;View on cloud</source>
        <translation>&amp;Görüntüle Bulutta</translation>
    </message>
    <message>
        <source>view this library on seahub</source>
        <translation>bu kütüphaneyi seahub&apos;da görüntüle</translation>
    </message>
    <message>
        <source>Share to user</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share this library to a user</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share to group</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share this library to a group</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Open cloud file browser</source>
        <translation>&amp;Aç bulut dosya tarayıcısı</translation>
    </message>
    <message>
        <source>open this library in embedded Cloud File Browser</source>
        <translation>bu kütüphaneyi Bulut Dosya Tarayıcısına gömülü aç</translation>
    </message>
    <message>
        <source>&amp;Leave share</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>leave share</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Resync this library</source>
        <translation>Bu kütüphaneyi &amp;Yeniden Senkronize Et</translation>
    </message>
    <message>
        <source>unsync and resync this library</source>
        <translation>bu kütüphanenin senkronizasyonu sonlandır ve yeniden senkronize et</translation>
    </message>
    <message>
        <source>Set sync &amp;Interval</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>set sync interval for this library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure to unsync the library &quot;%1&quot;?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure to resync the library &quot;%1&quot;?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure to overwrite the file &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to unsync library &quot;%1&quot;</source>
        <translation>&quot;%1&quot; kütüphanesinin senkronizasyonu sonlandırılamadı.</translation>
    </message>
    <message>
        <source>Are you sure you want to leave the share &quot;%1&quot;?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Leaving share failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to cancel this task:

 %1</source>
        <translation>Bu görev iptal edilemedi:

 %1</translation>
    </message>
    <message>
        <source>The download has been canceled</source>
        <translation>İndirme iptal edildi</translation>
    </message>
    <message>
        <source>You do not have permission to upload to this folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to overwrite file &quot;%1&quot; with itself</source>
        <translation> &quot;%1&quot; dosyası kendi üzerine yazılamıyor</translation>
    </message>
    <message>
        <source>Unable to delete file &quot;%1&quot;</source>
        <translation>&quot;%1&quot; dosyası silinemedi</translation>
    </message>
    <message>
        <source>Failed to upload file: %1</source>
        <translation>Dosya yüklenemedi: %1</translation>
    </message>
    <message>
        <source>Sync Interval (In seconds):</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Set Sync Internval For Library &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ReposTab</name>
    <message>
        <source>Search libraries</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>retry</source>
        <translation>tekrar dene</translation>
    </message>
    <message>
        <source>Failed to get libraries information&lt;br/&gt;Please %1</source>
        <translation>Kütüphane bilgisi alınamadı&lt;br/&gt;Lütfen %1</translation>
    </message>
</context>
<context>
    <name>SeafileApiClient</name>
    <message>
        <source>&lt;b&gt;Warning:&lt;/b&gt; The ssl certificate of this server is not trusted, proceed anyway?</source>
        <translation>&lt;b&gt;Uyarı:&lt;/b&gt; Bu sunucunun ssl sertifikası güvenilir deği, yine de devam edilsin mi?</translation>
    </message>
</context>
<context>
    <name>SeafileApplet</name>
    <message>
        <source>failed to add default account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to initialize log: %s</source>
        <translation>Log %s başlatılamadı</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SeafileLinkDialog</name>
    <message>
        <source>%1 Internal Link</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Panoya kopyala</translation>
    </message>
    <message>
        <source>%1 Web Link:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 Protocol Link:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation>Tamam</translation>
    </message>
</context>
<context>
    <name>SeafileRpcClient</name>
    <message>
        <source>failed to load ccnet config dir %1</source>
        <translation>ccnet config dir %1 yüklenemedi.</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Bilinmeyen hata</translation>
    </message>
</context>
<context>
    <name>SeafileTrayIcon</name>
    <message>
        <source>Disable auto sync</source>
        <translation>Oto senkronizasyonu devre dışı bırak</translation>
    </message>
    <message>
        <source>Enable auto sync</source>
        <translation>Oto senkronizasyonu etkinleştir</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Çık</translation>
    </message>
    <message>
        <source>Show main window</source>
        <translation>Ana pencereyi göster</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <source>Open %1 &amp;folder</source>
        <translation>Aç &amp;dosya  %1</translation>
    </message>
    <message>
        <source>open %1 folder</source>
        <translation>%1 dosyasını aç</translation>
    </message>
    <message>
        <source>Open &amp;logs folder</source>
        <translation>&amp;logs klasörünü aç</translation>
    </message>
    <message>
        <source>Show file sync errors</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Hakkında</translation>
    </message>
    <message>
        <source>Show the application&apos;s About box</source>
        <translation>Uygulamanın Hakkında kutusunu göster</translation>
    </message>
    <message>
        <source>&amp;Online help</source>
        <translation>&amp;Çevrimiçi Yardım</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Dosya</translation>
    </message>
    <message>
        <source>auto sync is disabled</source>
        <translation>Oto senkronizasyon devre dışı bırakıldı</translation>
    </message>
    <message>
        <source>Uploading</source>
        <translation>Yüklüyor</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>İndiriyor</translation>
    </message>
    <message>
        <source>open %1 log folder</source>
        <translation>%1 log klasörünü aç</translation>
    </message>
    <message>
        <source>open %1 online help</source>
        <translation>%1 online yardımı aç</translation>
    </message>
    <message>
        <source>some servers not connected</source>
        <translation>bazı sunucular bağlı değil</translation>
    </message>
</context>
<context>
    <name>SearchResultListView</name>
    <message>
        <source>&amp;Show in folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show in folder</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SearchTab</name>
    <message>
        <source>Search files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>retry</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to search&lt;br/&gt;Please %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ServerStatusDialog</name>
    <message>
        <source>Servers connection status</source>
        <translation>Sunucunun bağlantı durumu</translation>
    </message>
    <message>
        <source>connected</source>
        <translation>bağlı</translation>
    </message>
    <message>
        <source>disconnected</source>
        <translation>bağlı değil</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
</context>
<context>
    <name>SetRepoPasswordDialog</name>
    <message>
        <source>Please provide the library password</source>
        <translation>Lütfen kütüphane şifresini giriniz</translation>
    </message>
    <message>
        <source>Provide the password for library %1</source>
        <translation>%1 kütüphanesi için şifre giriniz</translation>
    </message>
    <message>
        <source>Please enter the password</source>
        <translation>Lütfen şifreyi giriniz</translation>
    </message>
    <message>
        <source>Incorrect password</source>
        <translation>Hatalı şifre</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Bilinmeyen hata</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Tamam</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal et</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <source>Auto start %1 after login</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Hide %1 Icon from the dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>None</source>
        <translation>Hiç</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>HTTP Proxy</translation>
    </message>
    <message>
        <source>Socks5 Proxy</source>
        <translation>Socks5 Proxy</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You have changed languange. Restart to apply it?</source>
        <translation>Dili değiştirdiniz. Uygulamak için yeniden başlatılsın mı?</translation>
    </message>
    <message>
        <source>The proxy host address can&apos;t be empty</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The proxy port is incorrect</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Proxy username can&apos;t be empty</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Proxy password can&apos;t be empty</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Hide main window when started</source>
        <translation>Başlarken ana pencereyi gizle</translation>
    </message>
    <message>
        <source>Notify when libraries are synchronized</source>
        <translation>Kütüphaneler senkronize edilince bildir</translation>
    </message>
    <message>
        <source>Enable sync temporary files of MSOffice/Libreoffice</source>
        <translation>MSOffice/Libreoffice &apos;deki geçici dosyaların senkronizasyonunu etkinleştir</translation>
    </message>
    <message>
        <source>Download speed limit (KB/s):</source>
        <translation>İndirme hız limiti </translation>
    </message>
    <message>
        <source>Upload speed limit (KB/s):</source>
        <translation>Yükleme hız limiti (KB/s):</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Temel</translation>
    </message>
    <message>
        <source>Do not automatically unsync a library</source>
        <translation>Bir kütüphaneyi senkronize etmeyi otomatik olarak durdurma</translation>
    </message>
    <message>
        <source>Do not automatically unsync a library when its local directory is removed or unaccessible for other reasons.</source>
        <translation>Bir kütüphaneyi lokal dizini kaldırıldığında ya da başka bir nedenle erişilmez olduğunda senkronize etmeyi otomatik olarak durdurma</translation>
    </message>
    <message>
        <source>Do not unsync a library when not found on server</source>
        <translation>Bir kütüphaneyi sunucuda bulunmadığında senkronize etmeyi durdurma</translation>
    </message>
    <message>
        <source>Do not automatically unsync a library when it&apos;s not found on server</source>
        <translation>Bir kütüphane sunucuda bulunmadığında senkronize etmeyi otomatik olarak sonlandırma.</translation>
    </message>
    <message>
        <source>Enable FinderSync Extension</source>
        <translation>FinderSync uzantısını etkinleştir</translation>
    </message>
    <message>
        <source>Enable Explorer Extension</source>
        <translation>Explorer uzantısını etkinleştir</translation>
    </message>
    <message>
        <source>Check for updates automatically</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Do not verify server certificate in HTTPS syncing</source>
        <translation>HTTPS senkronizasyonunda sunucu sertifası doğrulamayın</translation>
    </message>
    <message>
        <source>Enable syncing with an existing folder with a different name</source>
        <translation>Başka bir isimli mevcut bir dosya ile eşitlemeyi etkinleştir</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Gelişmiş</translation>
    </message>
    <message>
        <source>Language (need restart)</source>
        <translation>Dil (yeniden başlatma gerekir)</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Dil</translation>
    </message>
    <message>
        <source>Proxy Type:</source>
        <translation>Proxy Çeşidi:</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Host:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Kullanıcı adı:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Şifre:</translation>
    </message>
    <message>
        <source>Proxy server requires a password</source>
        <translation>Proxy suucu şifre gerektirir</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Ağ</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Tamam</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal et</translation>
    </message>
</context>
<context>
    <name>SharedItemDelegate</name>
    <message>
        <source>Read Write</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Read Only</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remove Share</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SharedItemsTableModel</name>
    <message>
        <source>Click to edit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Created by %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Read Write</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Read Only</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Group</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>User</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Permission</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The previous operation is still in progres</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SharedLinkDialog</name>
    <message>
        <source>Share Link</source>
        <translation>Bağlantı Paylaş</translation>
    </message>
    <message>
        <source>Share link:</source>
        <translation>Bağlantı paylaş:</translation>
    </message>
    <message>
        <source>Direct Download</source>
        <translation>Doğrudan İndirme</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Panoya kopyala</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Tamam</translation>
    </message>
</context>
<context>
    <name>ShibLoginDialog</name>
    <message>
        <source>Login with Shibboleth</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to save current account</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SslConfirmDialog</name>
    <message>
        <source>Untrusted Connection</source>
        <translation>Güvenilmeyen Bağlantı</translation>
    </message>
    <message>
        <source>%1 uses an invalid security certificate. The connection may be insecure. Do you want to continue?</source>
        <translation>%1 geçersiz bir güvenlik sertifikası kullanıyor. Bağlantı güvenilir olmayabilir. Devam etmek istiyor musunuz?</translation>
    </message>
    <message>
        <source>Current RSA key fingerprint is %1</source>
        <translation>Mevcut RSA anahtar parmakizi %1</translation>
    </message>
    <message>
        <source>Previous RSA key fingerprint is %1</source>
        <translation>Önceki RSA anahtar parmakizi %1</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Remember my choice</source>
        <translation>Seçimimi hatırla</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Evet</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Hayır</translation>
    </message>
</context>
<context>
    <name>StarredFilesListView</name>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Aç</translation>
    </message>
    <message>
        <source>Open this file</source>
        <translation>Bu dosyayı aç</translation>
    </message>
    <message>
        <source>view on &amp;Web</source>
        <translation>Web&apos;de &amp;Görüntüle</translation>
    </message>
    <message>
        <source>view this file on website</source>
        <translation>bu dosyayı websitesinde görüntüle</translation>
    </message>
</context>
<context>
    <name>StarredFilesTab</name>
    <message>
        <source>retry</source>
        <translation>tekrar dene</translation>
    </message>
    <message>
        <source>Failed to get starred files information&lt;br/&gt;Please %1</source>
        <translation>Yıldızlı dosyaların bilgileri alınamadı&lt;br/&gt;Lütfen %1</translation>
    </message>
    <message>
        <source>You have no starred files yet.</source>
        <translation>Henüz yıldızlı dosyanız yok</translation>
    </message>
</context>
<context>
    <name>SyncErrorsDialog</name>
    <message>
        <source>File Sync Errors</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No sync errors.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SyncErrorsTableModel</name>
    <message>
        <source>Double click to open the library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Path</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Time</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UninstallHelperDialog</name>
    <message>
        <source>Uninstall %1</source>
        <translation>%1&apos;i kaldır</translation>
    </message>
    <message>
        <source>Do you want to remove the %1 account information?</source>
        <translation>%1 hesabının bilgilerini kaldırmak istiyor musunuz?</translation>
    </message>
    <message>
        <source>Removing account information...</source>
        <translation>Hesap bilgileri kaldırılıyor...</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>text</source>
        <translation>metin</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Evet</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Hayır</translation>
    </message>
</context>
</TS>